# Example Package

## What is it?

An Example.

## Main Features

- **Example** is an example.

## Where to get it

Example-Package can be installed from PyPI using `pip`:

```bash
pip install example-package
```

## Interface
